@@ -8,7 +8,7 @@
 
 G_BEGIN_DECLS
 
-/* enumerations from "/usr/obj/i386/gst-plugins-bad-0.10.17/gst-plugins-bad-0.10.17/gst-libs/gst/interfaces/photography.h" */
+/* enumerations from "/usr/ports/pobj/gst-plugins-bad-0.10.19/gst-plugins-bad-0.10.19/gst-libs/gst/interfaces/photography.h" */
 GType gst_white_balance_mode_get_type (void);
 #define GST_TYPE_WHITE_BALANCE_MODE (gst_white_balance_mode_get_type())
 GType gst_colour_tone_mode_get_type (void);
@@ -23,6 +23,10 @@ GType gst_photo_caps_get_type (void);
 #define GST_TYPE_PHOTO_CAPS (gst_photo_caps_get_type())
 GType gst_photo_shake_risk_get_type (void);
 #define GST_TYPE_PHOTO_SHAKE_RISK (gst_photo_shake_risk_get_type())
+GType gst_flicker_reduction_mode_get_type (void);
+#define GST_TYPE_FLICKER_REDUCTION_MODE (gst_flicker_reduction_mode_get_type())
+GType gst_focus_mode_get_type (void);
+#define GST_TYPE_FOCUS_MODE (gst_focus_mode_get_type())
 G_END_DECLS
 
 #endif /* __GST_PHOTOGRAPHY_ENUM_TYPES_H__ */
